import type { BufferConfig } from '../../../types';
import { BatchLogRecordProcessorBase } from '../../../export/BatchLogRecordProcessorBase';
export declare class BatchLogRecordProcessor extends BatchLogRecordProcessorBase<BufferConfig> {
    protected onShutdown(): void;
}
//# sourceMappingURL=BatchLogRecordProcessor.d.ts.map